#
# spec file for package ansible-documentation
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ansible-documentation
Version:        2.18.6
Release:        1.1
Summary:        Ansible community documentation and example files
License:        GPL-3.0-only
URL:            https://github.com/ansible/ansible-documentation
Source:         ansible-documentation-%{version}.tar.gz
BuildRequires:  ansible-core = %{version}
BuildRequires:  fdupes
Requires:       ansible-core = %{version}
BuildArch:      noarch

%description
User documentation and example files related to the Ansible package and Ansible core.

%prep
%autosetup -p1 -n ansible-documentation-%{version}

%build

%install
mkdir -p %{buildroot}%{_sysconfdir}/ansible/
cp examples/hosts %{buildroot}%{_sysconfdir}/ansible/
cp examples/ansible.cfg %{buildroot}%{_sysconfdir}/ansible/

%files
%doc README.md
%license COPYING
%config(noreplace) %{_sysconfdir}/ansible/ansible.cfg
%config(noreplace) %{_sysconfdir}/ansible/hosts

%changelog
* Tue May 20 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.18.6:
  * ci: refresh dev dependencies (#2642)
  * Only run pr_labeler on devel or stable-* branches (#2552)
    (#2606)
  * First pass at adding notes requested in #1638 (#2566) (#2600)
  * Update interpreter_discovery for changes made in ansible-core
    2.17 (#2438) (#2609)
  * ci: refresh dev dependencies (#2623)
  * Update networking guides to be compatible with ansible-core
    2.18+. (#2586) (#2594)
  * Add one sentence per line to the style guide (#2470) (#2579)
  * add EXAMPLE to sample passwords etc (#2574) (#2583)
  * ci: refresh dev dependencies (#2589)
  * ci: refresh dev dependencies (#2570)
  * Update Ansible 11 porting guide for 11.5.0 release (#2547)
    (#2564)
  * Update example image from `fedora:39` to `fedora:42` (#2541)
    (#2558)
  * Update developing_modules_documenting.rst (#2551) (#2555)
  * ci: refresh dev dependencies (#2537)
  * Module format and doc: tidy up (#2502) (#2542)
* Thu Apr 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.18.5:
  * ci: refresh dev dependencies (#2515)
  * ci: use official create-github-app-token action (#2499) (#2503)
  * ci: refresh dev dependencies (#2495)
  * Add missing closing parentheses (#2467) (#2485)
  * ci: refresh dev dependencies (#2475)
  * Fix codespell issues (#2478) (#2482)
  * update the pip-compile details in the readme (#2472) (#2479)
  * Add Ansible 11.4.0 porting guide. (#2468) (#2469)
* Tue Mar 25 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.18.4:
  * add fest banner (#2464) (#2466)
  * Update module developement (#2427) (#2461)
  * union filter documented incorrectly (#2403) (#2458)
  * fixes and updates to inventory intro (#2416) (#2455)
  * Update playbooks_error_handling.rst (#2095) (#2454)
  * Introduce a new section for managing z/OS UNIX mainframe hosts
    with Ansible. (#2424) (#2451)
  * Remove thaumos from SC (#2440) (#2450)
  * testing_sanity.rst: improvement (#2441) (#2447)
  * Involuntarily leaving SC: Allow PM on forum (#2393) (#2445)
  * pr_labeler: fix error in pyproject.toml (#2432) (#2435)
  * Update Ansible 11 porting guide for 11.3.0 release (#2425)
    (#2426)
* Tue Feb 25 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.18.3:
  * address broken links in dev and appendices sections (#2402)
    (#2423)
  * Fix YAML syntax, adjust more code block languages (#2408)
    (#2419)
  * Fix broken link markup. (#2412) (#2415)
  * Bump wntrblm/nox from 2024.10.09 to 2025.02.09 (#2409)
  * Update RST files to specify codeblock language attributes
    (#2382) (#2407)
  * Add SC member forum names (#2392) (#2395)
  * intro_inventory: Update ignore extension setting (#2372)
    (#2401)
  * Clarify handlers insertion order (#2359) (#2398)
  * Remove incorrect parts from docs. (#2388) (#2391)
  * Update Ansible 11 porting guide for 11.2.0 release. (#2380)
    (#2381)
  * Skip auto-generated porting guides for rstcheck. (#2376)
    (#2379)
* Tue Jan 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.18.2:
  * [stable-2.18] bump antsibull-docs version to 2.16.3 (#2369)
  * remove tag session from noxfile (#2368)
  * add runpip instructions for dependencies (#2322) (#2351)
  * [stable 2.18] remove the relaxed reqs (#2361)
  * How Can I Help? page: add a ref to collections quick-start
    guide (#2346) (#2347)
  * Update platform_junos.rst (#2141) (#2343)
  * callback event reception order (#2333) (#2341)
  * fix(style-guide): Add definition for "ID" abbreviation in
    spelling and word choice guide (#2332) (#2337)
  * remove 2.9 from version switcher (#2329) (#2331)
  * Bump antsibull-docs to 2.16.2. (#2317) (#2325)
  * intro_bsd: Update docs for the current FreeBSD and OpenBSD
    (#2318) (#2327)
  * [stable-2.18] ci: refresh dev dependencies (#2311)
  * [Needs SC review] community/other_tools_and_programs.rst:
    update (#2284) (#2305)
  * fix typo (#2293) (#2294)
  * ci: refresh dev dependencies (#2300)
  * intro_installation.rst: fix formatting (#2289) (#2292)
  * Use name instead of source for the documentation on installing
    directories (#2259) (#2287)
  * fixes #2177 for stable-2.18 (#2262)
  * Link to templating functions from the variables page (#2258)
    (#2283)
  * Emacs editor integration of ansible-lint
    ansible/ansible-lint#1326 (#2239) (#2278)
  * fix file name to execution-environment.yml (#2240) (#2280)
  * ansible-vault show how to decrypt strings (#2238) (#2274)
  * ci: refresh dev dependencies (#2268)
  * run_execution_environment.rst: fix a note (#2253) (#2256)
  * Add porting guide for Ansible 9.13.0 (#2243) (#2250)
  * Add porting guide for Ansible 10.7.0 (#2242) (#2247)
  * Add porting guide for Ansible 11.1.0 (#2241) (#2245)
* Tue Dec  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.18.1:
  * ci: refresh dev dependencies (#2231)
  * Add package to getting started ee (#2228) (#2237)
  * ci: refresh dev dependencies (#2226)
  * update intersphinx links for Ansible 11 (#2212) (#2221)
  * [stable-2.18] Update docs build dependencies; bump
    antsibull-docs to 2.16.1 (#2218)
  * fix anisble 11 changelog link (#2213) (#2214)
  * LICENSE and DCO in CODEOWNERS (#2205)
  * update release table for Ansible 11 (#2158) (#2204)
  * update version switcher for Ansible 11 (#2159) (#2202)
  * Add porting guide for Ansible 11.0.0 (#2197) (#2198)
  * fix bad formating (#2192) (#2196)
  * add note and link for galaxy.yml details (#2092) (#2118)
  * update backport instructions (#2183) (#2191)
  * update release table with 2.15 EOL (#2184) (#2189)
  * Update some info on distribution servers (#2119) (#2182)
  * fix: Remove stray reference to group_by_module (#2142) (#2146)
  * remove swiftype search engine (#2140) (#2154)
  * update latest doc version to 11 (#2160)
  * ci: refresh dev dependencies (#2173)
  * [stable-2.18] Update docs build dependencies, use
    antsibull-docs 2.16.0 (#2169)
  * Fix the misspelled word 'not' (#2161) (#2166)
  * Add porting guide for Ansible 11.0.0rc1 (#2135) (#2139)
  * comment the extra banner to remove community survey (#2132)
    (#2137)
  * build_execution_environment: add working version of Fedora
    (#2126) (#2129)
  * Update Ansible 11 porting guide. (#2113) (#2114)
  * Update ansible-core 2.18 and Ansible 11 porting guides (#2108)
    (#2109)
  * Add porting guide for Ansible 11.0.0b1 (#2101) (#2107)
  * Add porting guide for Ansible 10.6.0 (#2100) (#2105)
  * Add porting guide for Ansible 9.12.0 (#2099) (#2102)
  * update version switcher for 2.18 (#2090) (#2098)
  * Change 2.18 to correct version (#2089)
* Sat Nov 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.18.0:
  * Added 2.18 porting guide (#2076) (#2091)
  * Update module default groups documentation (#1893) (#2074)
  * fix: correct typos (#2062) (#2071)
  * nox pip-compile: temporarily pin pip version (#2085) (#2088)
  * Add details of interactions between notifications and loops
    (#597) (#2067)
  * Remove ansible-test sanity from local module development
    (#2034) (#2061)
  * add example of extending ansible_facts (#2040) (#2055)
  * Add rules on moving content to collections outside of Ansible
    (#1971) (#2053)
  * make survey more prominent (#2037) (#2046)
  * remove build workflow from stable (#2032)
  * Bump wntrblm/nox from 2024.04.15 to 2024.10.09 (#2006) (#2041)
  * fix network_best_practices_2.5.rst (#2036) (#2039)
  * docs typo, missing a space (#2004) (#2031)
  * use standard indentation (#2005) (#2029)
  * Tagging nuance (#1900) (#2021)
  * Remove unsupported API example (#1939) (#2019)
  * Update docs build to support the new antsibull-docs 2.15.0
    features (#2001) (#2018)
  * Add ecosystem_project_resources.rst document (#2007) (#2011)
  * [stable-2.18] support pip-compile check mode and remove
    pip-compile workflows from stable branch (#1946)
  * Add porting guide for Ansible 11.0.0a2 (#2014) (#2015)
  * Upgrade antsibull-docs to 2.15.0 and antsibull-core to 3.3.0.
    (#1994) (#1995)
  * [PR #1996/d6984678 backport][stable-2.18] update docs team info
    page (#1999)
  * Add porting guide for Ansible 9.11.0. (#1988) (#1992)
  * Add porting guide for Ansible 10.5.0. (#1987) (#1993)
  * Update playbooks_error_handling.rst (#1982) (#1986)
  * add project survey 2024 banner (#1979) (#1981)
  * Remove tagger script from stable (#1933)
  * issue #1925 ee getting started missing content (#1975) (#1978)
  * Remove no longer applicable part. (#1970) (#1974)
  * Moved when condition after task name for block example (#1961)
    (#1969)
  * Update introduction.rst (#1960) (#1965)
  * playbooks_filters: Mention the usage of the
    ansible.builtin.split filter (#1929) (#1959)
  * fix 2.18 python requirement version (#1945) (#1955)
  * Add Ansible 11 porting guide (#1943) (#1944)
  * many: Fix title case of Git references (#1938) (#1942)
  * change core branch to 2.18 (#1931)
  * getting_started_ee/build_execution_environment.rst: temporary
    sample fix (#1924)
  * Update other_tools_and_programs.rst (#1915)
  * lint actionlint: enable shellcheck integration
  * nox: add actionlint to lint Github Actions workflows
  * pr_labeler: re-architect triager script (#1882)
  * Nightly builds for package docs publishing workflow (#1869)
  * Add caveat about installing collections from git (#1894)
  * ci: refresh docs build dependencies (#1891)
  * Fix Ansible 11 roadmap (#1892)
  * ci: refresh dev dependencies (#1888)
  * Revamp Windows docs (#1820)
  * clone-core: update clone core script to remove old files
  * nox clone-core: allow passing extra args to script
  * Change Getting started EE guide reference to point to the
    relevant location (#1877)
  * Add documentation for loop_control option to stop a loop early
    (#1764)
  * Replace communication links with a link to communication guide,
    part 2 (#1864)
  * Correct information about plugin enabling (#1760)
  * Give tag workflow access to github-bot environment. (#1866)
  * ci: add workflow to create core tags automatically (#1863)
  * Replace communication links with a link to communication guide,
    part 1 (#1851)
  * Restore community ee content (#1852)
  * Add porting guide for Ansible 9.10.0 (#1854)
  * Add porting guide for Ansible 10.4.0 (#1853)
  * ci: refresh dev dependencies (#1845)
  * [devel] ci: refresh docs build dependencies (#1835)
  * Bump antsibull-docs to 2.14.0; add antsibull-docutils and
    antsibull-fileutils. (#1837)
  * community_steering_committee.rst: fix collection requirements
    link (#1828)
  * ci: refresh dev dependencies (#1834)
  * add check-deploy job to publish workflow (#1814)
  * ci: refresh dev dependencies (#1826)
  * ci: refresh docs build dependencies (#1827)
  * steering_committee_membership: clarify guidelines about team
    representatives (#1806)
  * Clarify any_errors_fatal behavior change in 2.17 porting guide
    (#1815)
  * steering_committee_membership: fix rst link syntax error
    (#1805)
  * nox: support nox uv backend (#1757)
  * Issue1682_nightly_build_default_values (#1727)
  * ci: refresh docs build dependencies (#1797)
  * [devel] ci: refresh dev dependencies (#1794)
  * Bump antsibull-docs and antsibull-docs-parser versions (#1799)
  * Fix broken list markup in the "Installing collections"
    documentation. (#1798)
  * Fix links in collection requirements. (#1785)
  * fix indents network documents (#1776)
  * Ansible 11 roadmap (#1729)
  * ci: ensure ansible-core files exist before running docs build
    (#1756)
  * ci: refresh docs build dependencies (#1771)
  * add note about arguments in shebang in modules (#1718)
  * ci: refresh dev dependencies (#1770)
  * dev pip-compile: switch devel branch pip-compile to 3.11
    (#1616)
  * ci: refresh docs build dependencies (#1708)
  * ci: refresh dev dependencies (#1744)
  * [Needs SC vote before merging] Collection requirements: add
    Forum-related reqs (#1703)
  * Add porting guide for Ansible 10.3.0. (#1746)
  * Add porting guide for Ansible 9.9.0. (#1745)
  * setup.cfg and setup.py are gone since
    https://github.com/ansible/ansible/commit/68515abf97dfc769c9aed2ba457ed7b8b2580a5c
    (#1747)
  * Added 'direct' to general precedence (#1740)
  * Update integration test guide docker flag usage (#1731)
  * ci: refresh dev dependencies (#1730)
  * ci: refresh dev dependencies (#1722)
  * add vault password file example (#1696)
  * Be more explicit about registering with a loop (#1709)
  * ci: refresh dev dependencies (#1707)
  * Issue #1633 nox session for tagging (#1649)
  * ci: refresh docs build dependencies (#1691)
  * Move community_topics_workflow to docs.ansible.com (#1028)
  * Add porting guide for Ansible 9.8.0. (#1698)
  * Add porting guide for Ansible 10.2.0. (#1697)
  * restore anchor in communication guide (#1692)
  * collection_requirements: fix typo (#1684)
  * Remove language option from workflow (#1681)
  * notify docs matrix channel on docs build failures (#1651)
  * remove the schedule from the workflow dispatch job (#1683)
  * Adding daily schedule to CI build (#1659)
  * Nightly builds for package docs publishing workflow (#1663)
  * ci: refresh docs build dependencies (#1676)
  * ci: refresh dev dependencies (#1675)
  * Output workflow parameters for approval details (#1650)
  * ci: refresh docs build dependencies (#1658)
  * ci: refresh dev dependencies (#1657)
  * communication guide: overhaul (#1667)
  * [WIP, needs vote before merging] collection_requirements.rst:
    update (#1422)
  * docs/docsite/rst/dev_guide/developing_program_flow_modules.rst:
    avoid using aliases (#1539)
  * Remove references to archived ansible/ansible-examples
    repository (#1653)
  * Remove reference of scp_if_ssh option (#1346)
  * Integrate the `alls-green` action into the main GHA CI workflow
    (#1639)
  * fix Ansible architecture docs (#1637)
  * fix Validate data against set criteria with Ansible doc (#1636)
  * ci: refresh docs build dependencies (#1635)
  * Remove latest symlink from publishing workflow (#1615)
  * ci: refresh dev dependencies (#1634)
  * Revert "Add example /usr/bin/env python as Python interpreter
    (#280)" (#1629)
  * developing_collections_migrating.rst: update (#1605)
  * Replace WG list with a pointer to the forum groups . (#1596)
  * Update unit test document (#1597)
  * Update playbooks_loops.rst (#1617)
  * Add 2.18 support matrix entry (#1618)
  * Add porting guide for Ansible 10.1.0. (#1610)
  * Add porting guide for 9.7.0. (#1609)
  * rm translation from rtd url
  * use the package version as the branch name (#1600)
  * Fix typo in communication.rst (#1598)
  * ci: refresh docs build dependencies
  * ci: refresh dev dependencies
  * ci: refresh dev dependencies
  * clarify how to verify collection-level docs (#1589)
  * add steps to deploy doc build assets (#1353)
  * Add 2.18 roadmap (#1590)
  * Fix up PowerShell and Windows support lifecycle (#1587)
  * ci: refresh docs build dependencies
  * cause people keep doing this (#1567)
  * Update uptime.py (#1524)
  * Update playbooks_loops.rst (#1569)
  * Update the Ansible 10 porting guide. (#1570)
  * remove mailchimp subscribe from docs
  * Add Ansible 10 to intersphinx links
  * Update playbooks_advanced_syntax.rst
  * Update release table for Ansible 10 and 9 (#1543)
  * update conf.py for Ansible 10 (#1544)
  * Add Ansible community 10.0.0 porting guide (#1555)
  * Update playbooks_blocks.rst (#1546)
  * ci: refresh docs build dependencies
  * ci: refresh dev dependencies
  * ci: refresh dev dependencies
  * Python collection requirements: restructure (#1459)
  * fix minor typo in Makefile
  * Fix
  * Requesting a collection: replace overview links
  * ci: refresh docs build dependencies
  * release_and_maintenance: mark 8.x unmaintained as 8.7.0
    released (#1522)
  * resolves #1491 adding assert details
  * Add tagger section to README per 1272 (#1460)
  * mark 2.14 EOL in the release table (#1502)
  * update backport instructions for 2.17 (#1504)
  * Move Ansible package collection removal process to
    docs.ansible.com (#1492)
  * Update collection_checklist.md links to point to new location
    (#1505)
  * Add Ansible community 10.0.0b1 porting guide (#1494)
  * Add Ansible community 9.6.0 porting guide (#1493)
  * update version switcher to suppor 2.17 (#1464)
  * collection_requirements: update community topic links (#1421)
  * Fix list.
  * ci: refresh dev dependencies
  * Update docs/docsite/rst/command_guide/cheatsheet.rst
  * make it a note
  * Update docs/docsite/rst/playbook_guide/playbooks_loops.rst
  * Update docs/docsite/rst/playbook_guide/playbook_pathing.rst
  * Remove depreciated platforms reference (#1458)
  * Update community topics links (#1451)
  * revert subheading
  * edits and suggestions
  * Add Ansible 10.0.0a3 porting guide. (#1452)
  * Remove output
  * [Needs SC vote before merging] SC: update collection inclusion
    procedure (#1256)
  * ci: refresh docs build dependencies
  * ci: refresh dev dependencies
  * ci: refresh dev dependencies
  * ci: refresh docs build dependencies (#1409)
  * Document the possibility of vars/main and defaults/main being
    directories (#1320)
  * clarify backup_file (#1391)
  * Restore the umask note for building docs (#1400)
  * how_can_i_help page: rephrase the paragraph mentioning forums
    (#1410)
  * Update playbooks_reuse_roles.rst (#1415)
  * Add changelog link and update powershell range
  * intro_installation.rst: shells -> shell's to make possessive
    (#1420)
  * Bump antsibull-docs to 2.11.0. (#1417)
  * Minor rewording changes
  * removed example
  * Section on retrying with timeout pass 2
  * Code block edit.
  * Added a section on retrying tasks with timeout.
  * Adding explanation for combining until with loop (#1367)
  * update codespell ignore lines (#1366)
  * Integrate ansible-creator and devtools into the developing
    collections guide (#1302)
  * follows up on #1042 to remove smart from uptime script (#1340)
  * CONTRIBUTING: document backport labels and PR Merging (#1364)
  * New section on combining variables added (#1383)
  * Fix typos in style guide (#1368)
  * MUNI_TECH_WRITERS: Better documented local collections for
    playbooks #1129 (#1315)
  * Add Ansible 10.0.0a2 porting guide. (#1378)
  * moved Troubleshooting search paths subsection to the bottom of
    the page and moved the note with details about current work dir
    up, where it fits better
  * fix: tiny stylistic changes
  * Update .github/workflows/build-package-docs.yaml
  * ci: refresh docs build dependencies
  * ci: refresh dev dependencies
  * Add examples to clarify inventory plugin usage (#1347)
  * improve workflow syntax
  * update symlink step syntax in docs build workflow
  * fix: wording and structure changes (#1167)
  * mention of ANSIBLE_CONNECTION_PATH removed
  * changing location
  * 'for more information' added
  * docs: added section referencing changed_when (#1167)
  * comments integrated
  * example removed
  * comments integrated
  * fix: remove mention of 'connection_plugins'
  * Added a note describing how Ansible deals with relative tasks
    paths when using include_role vs when using include_taks /
    import_task
  * Add Ansible 9.5.1 porting guide. (#1312)
  * fix: connection keyword mentioned
  * fix: more consistent displaying of changed_when: True example
    (#1167)
  * Refactored the line about ansible not searching the current
    workdir.
  * replaced single backticks with double ones in places where
    syntax should be highlighted
  * Reworked headings
  * ci pip-compile-dev: add backport-2.17 label to PRs (#1310)
  * fix: spelling (#1167)
  * docs: wording (#1167)
  * Update docs/docsite/rst/dev_guide/developing_plugins.rst
  * fixes name of the upload artifact
  * docs: referencing defining-changed in playbooks_handlers
    (#1167)
  * Bump wntrblm/nox from 2024.03.02 to 2024.04.15
  * syntax fix
  * typo fix
  * ffeat: Relative path tip
  * ci: refresh docs build dependencies
  * ci: refresh dev dependencies
  * docs: example with changed_when: true (#1167)
  * Update playbooks_blocks.rst (#1190)
  * fix: highlight ssh, remove unnecessary sentence
  * fix: use backticks, all sentences on a new line
  * fix: reformat sentence, check intendations with yamllint
  * fix: add new example of the modules to clarify usage
  * Apply suggestions from code review
  * feat: mention ANSIBLE_CONNECTION_PATH (ansible#793)
  * fix: typo in url (ansible#1199)
  * fix: mentioned errors in the pull request
  * izpell
  * ci: refresh dev dependencies
  * ci: refresh docs build dependencies
  * Bump antsibull-docs to 2.10.0 (#1268)
  * Update playbooks_reuse_roles.rst
  * ansible-core 2.17 porting guide: remote Python version support
  * community_topics_workflow: fix formatting (#1270)
  * SC: move community_topics_workflow.md to docs.ansible.com
    (#1257)
  * [Needs SC vote before merging] Steering Committee: team
    membership (#1237)
  * Add Ansible 10.0.0a1 porting guide. (#1260)
  * feat: update the paramiko description
  * feat: remove depricated smart connection description in
    connection plugins
  * feat: remove the "smart option and rewrite the default
    connection type
  * change
  * tar cmd update
  * create latest symlink and include in tarball
  * fix up repository inputs
  * move env to top level
  * change input to ansible-package-version
  * use kebab-case for inputs
  * split cmd over multiple lines
  * add yaml start and fix indentation
  * rm quotes
  * update package version options
  * build package docs via gh action
  * edited
  * format tag.py
  * Update hacking/tagger/tag.py
  * update tagger for 2.17
  * Change
  * ansible doc
  * Update developing_modules_general.rst
* Thu Nov 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.17.6:
  * Update module default groups documentation (#1893) (#2073)
  * fix: correct typos (#2062) (#2070)
  * nox pip-compile: temporarily pin pip version (#2085) (#2087)
  * Add details of interactions between notifications and loops
    (#597) (#2066)
  * Remove ansible-test sanity from local module development
    (#2034) (#2060)
  * add example of extending ansible_facts (#2040) (#2054)
  * Add rules on moving content to collections outside of Ansible
    (#1971) (#2051)
  * make survey more prominent (#2037) (#2045)
  * Bump wntrblm/nox from 2024.04.15 to 2024.10.09 (#2006) (#2042)
  * fix network_best_practices_2.5.rst (#2036) (#2038)
  * docs typo, missing a space (#2004) (#2030)
  * use standard indentation (#2005) (#2027)
  * Tagging nuance (#1900) (#2020)
  * keep lockfiles in sync for stable-2.17 (#2023)
  * Update docs build to support the new antsibull-docs 2.15.0
    features (#2001) (#2017)
  * Add ecosystem_project_resources.rst document (#2007) (#2010)
  * [stable-2.17] support pip-compile check mode and remove
    pip-compile workflows from stable branch (#1947)
  * Upgrade antsibull-docs to 2.15.0 and antsibull-core to 3.3.0.
    (#1994) (#2002)
  * [PR #1996/d6984678 backport][stable-2.17] update docs team info
    page (#1998)
  * Add porting guide for Ansible 10.5.0. (#1987) (#1991)
  * Add porting guide for Ansible 9.11.0. (#1988) (#1990)
  * Update playbooks_error_handling.rst (#1982) (#1985)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.17.5:
  * add project survey 2024 banner (#1979) (#1980)
  * Remove tagger script from stable (#1934)
  * issue #1925 ee getting started missing content (#1975) (#1977)
  * Remove no longer applicable part. (#1970) (#1973)
  * Moved when condition after task name for block example (#1961)
    (#1968)
  * Update introduction.rst (#1960) (#1964)
  * playbooks_filters: Mention the usage of the
    ansible.builtin.split filter (#1929) (#1958)
  * many: Fix title case of Git references (#1938) (#1941)
  * getting_started_ee/build_execution_environment.rst: temporary
    sample fix (#1924) (#1927)
  * nox: add actionlint to lint Github Actions workflows (#1848)
    (#1910)
  * pr_labeler: re-architect triager script (#1882) (#1908)
  * Add caveat about installing collections from git (#1894)
    (#1898)
  * ci: refresh dev dependencies (#1890)
  * Change Getting started EE guide reference to point to the
    relevant location (#1877) (#1880)
  * Replace communication links with a link to communication guide,
    part 2 (#1864) (#1874)
  * Correct information about plugin enabling (#1760) (#1871)
  * Replace communication links with a link to communication guide,
    part 1 (#1851) (#1862)
  * Restore community ee content (#1852) (#1859)
  * Add porting guide for Ansible 9.10.0 (#1854) (#1857)
  * Add porting guide for Ansible 10.4.0 (#1853) (#1855)
  * Bump antsibull-docs to 2.14.0; add antsibull-docutils and
    antsibull-fileutils. (#1837) (#1846)
  * ci: refresh dev dependencies (#1842)
* Wed Sep 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.17.4:
  * community_steering_committee.rst: fix collection requirements
    link (#1828) (#1840)
  * ci: refresh dev dependencies (#1832)
  * ci: refresh dev dependencies (#1824)
  * steering_committee_membership: clarify guidelines about team
    representatives (#1806) (#1817)
  * Clarify any_errors_fatal behavior change in 2.17 porting guide
    (#1815) (#1816)
  * steering_committee_membership: fix rst link syntax error
    (#1805) (#1813)
  * nox: support nox uv backend (#1757) (#1810)
  * [Needs SC vote before merging] Steering Committee: team
    membership (#1237) (#1811)
  * Bump antsibull-docs and antsibull-docs-parser versions (#1799)
    (#1802)
  * [stable-2.17] ci: refresh dev dependencies (#1795)
  * tests: update pydantic version in lockfile (#1788)
  * Fix broken list markup in the "Installing collections"
    documentation. (#1798) (#1800)
  * Fix links in collection requirements. (#1785) (#1787)
  * ci: ensure ansible-core files exist before running docs build
    (#1756) (#1780)
  * fix indents network documents (#1776) (#1779)
  * add note about arguments in shebang in modules (#1718) (#1773)
  * ci: refresh dev dependencies (#1768)
  * ci: refresh dev dependencies (#1753)
  * [Needs SC vote before merging] Collection requirements: add
    Forum-related reqs (#1703) (#1761)
  * Add porting guide for Ansible 10.3.0. (#1746) (#1750)
  * Add porting guide for Ansible 9.9.0. (#1745) (#1749)
  * Added 'direct' to general precedence (#1740) (#1743)
* Tue Aug 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.17.3:
  * Update integration test guide docker flag usage (#1731) (#1737)
  * ci: refresh dev dependencies (#1730) (#1735)
  * ci: refresh dev dependencies (#1722) (#1726)
  * add vault password file example (#1696) (#1721)
  * Be more explicit about registering with a loop (#1709) (#1717)
  * [PR #1707/141ca118 backport][stable-2.17] ci: refresh dev
    dependencies (#1711)
  * Move community_topics_workflow to docs.ansible.com (#1028)
    (#1704)
  * Add porting guide for Ansible 9.8.0. (#1698) (#1701)
  * Add porting guide for Ansible 10.2.0. (#1697) (#1699)
* Tue Jul 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.17.2:
  * restore anchor in communication guide (#1692) (#1694)
  * collection_requirements: fix typo (#1684) (#1687)
  * [WIP, needs vote before merging] collection_requirements.rst:
    update (#1422) (#1664)
  * ci: refresh dev dependencies (#1675) (#1680)
  * ci: refresh dev dependencies (#1671)
  * communication guide: overhaul (#1667) (#1668)
  * docs/docsite/rst/dev_guide/developing_program_flow_modules.rst:
    avoid using aliases (#1539) (#1660)
  * Remove references to archived ansible/ansible-examples
    repository (#1653) (#1656)
  * Remove reference of scp_if_ssh option (#1346) (#1652)
  * Integrate the `alls-green` action into the main GHA CI workflow
    (#1639) (#1647)
  * fix Ansible architecture docs (#1637) (#1646)
  * fix Validate data against set criteria with Ansible doc (#1636)
    (#1642)
  * Revert "Add example /usr/bin/env python as Python interpreter
    (#280)" (#1629) (#1631)
  * Replace WG list with a pointer to the forum groups . (#1596)
    (#1625)
  * developing_collections_migrating.rst: update (#1605) (#1628)
  * Update unit test document (#1597) (#1624)
  * Update playbooks_loops.rst (#1617) (#1620)
  * Add porting guide for 9.7.0. (#1609) (#1613)
  * Add porting guide for Ansible 10.1.0. (#1610) (#1612)
  * Fix typo in communication.rst (#1598) (#1608)
* Sun Jul 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.17.1:
  * Merge pull request #1585 from ansible/pip-compile/devel/dev
  * clarify how to verify collection-level docs (#1589) (#1595)
  * Fix up PowerShell and Windows support lifecycle (#1587) (#1588)
  * cause people keep doing this (#1567) (#1584)
  * Update uptime.py (#1524) (#1581)
  * Update playbooks_loops.rst (#1569) (#1578)
  * Merge pull request #1568 from samccann/bullhorn-edit
  * Merge pull request #1566 from samccann/intersphinx
  * Update the Ansible 10 porting guide. (#1570)
  * Merge pull request #1562 from M15terHyde/patch-1
  * Merge pull request #1523 from
    oraNod/issue-1491/porting-guide-217
  * Update release table for Ansible 10 and 9 (#1543) (#1558)
  * update conf.py for Ansible 10 (#1544) (#1559)
  * Update playbooks_blocks.rst (#1546) (#1554)
  * Add Ansible community 10.0.0 porting guide (#1555) (#1556)
  * update to version 10 (#1551)
  * Merge pull request #1527 from ansible/pip-compile/devel/dev
  * Python collection requirements: restructure (#1459) (#1542)
  * Merge pull request #1529 from
    Andersson007/update_overview_links
  * Merge pull request #1530 from oraNod/fix-spelling
  * release_and_maintenance: mark 8.x unmaintained as 8.7.0
    released (#1522) (#1526)
  * mark 2.14 EOL in the release table (#1502) (#1521)
  * update backport instructions for 2.17 (#1504) (#1518)
  * Merge pull request #1321 from vojtam/feature/#357
  * Update collection_checklist.md links to point to new location
    (#1505) (#1506)
  * Move Ansible package collection removal process to
    docs.ansible.com (#1492) (#1508)
  * Add Ansible community 10.0.0b1 porting guide (#1494)
  * Add Ansible community 9.6.0 porting guide (#1493)
  * Merge pull request #1477 from ansible/pip-compile/devel/dev
  * update version switcher to suppor 2.17 (#1464) (#1486)
  * collection_requirements: update community topic links (#1421)
    (#1484)
* Sun Jul 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.17.0:
  major update to 2.17.0, no changelog.
  Full list of commits/changes see
  https://github.com/ansible/ansible-documentation/compare/v2.16.8...v2.17.0
* Wed Jun 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.8:
  * ci: refresh dev dependencies
  * clarify how to verify collection-level docs (#1589) (#1594)
  * cause people keep doing this (#1567) (#1583)
  * Update uptime.py (#1524) (#1580)
  * Update playbooks_loops.rst (#1569) (#1577)
  * Merge pull request #1568 from samccann/bullhorn-edit
  * Merge pull request #1566 from samccann/intersphinx
  * Merge pull request #1562 from M15terHyde/patch-1
  * update conf.py for Ansible 10 (#1544) (#1560)
  * Update release table for Ansible 10 and 9 (#1543) (#1557)
  * Update playbooks_blocks.rst (#1546) (#1553)
  * Merge pull request #1527 from ansible/pip-compile/devel/dev
  * Python collection requirements: restructure (#1459) (#1541)
  * Merge pull request #1529 from
    Andersson007/update_overview_links
  * Merge pull request #1530 from oraNod/fix-spelling
  * release_and_maintenance: mark 8.x unmaintained as 8.7.0
    released (#1522) (#1525)
  * mark 2.14 EOL in the release table (#1502) (#1520)
  * update backport instructions for 2.17 (#1504) (#1516)
  * Merge pull request #1321 from vojtam/feature/#357
  * Update collection_checklist.md links to point to new location
    (#1505) (#1507)
  * Move Ansible package collection removal process to
    docs.ansible.com (#1492) (#1509)
  * Add Ansible community 9.6.0 porting guide (#1493)
  * ci: refresh dev dependencies
  * update version switcher to suppor 2.17 (#1464) (#1485)
  * collection_requirements: update community topic links (#1421)
    (#1483)
* Thu May 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.7:
  * Merge pull request #1479 from felixfontein/fix
  * Merge pull request #1416 from sourn00dl/feature#881
  * Merge pull request #1248 from BhattacharjeeSutapa/ansible-doc
  * Update community topics links (#1451) (#1469)
  * community_topics_workflow: fix formatting (#1270) (#1467)
  * SC: move community_topics_workflow.md to docs.ansible.com
    (#1257) (#1466)
  * Merge pull request #1408 from ansible/pip-compile/devel/dev
  * Update playbooks_reuse_roles.rst (#1415) (#1429)
  * clarify backup_file (#1391) (#1441)
  * Document the possibility of vars/main and defaults/main being
    directories (#1320) (#1443)
  * how_can_i_help page: rephrase the paragraph mentioning forums
    (#1410) (#1433)
  * Restore the umask note for building docs (#1400) (#1437)
  * intro_installation.rst: shells -> shell's to make possessive
    (#1420) (#1424)
  * Bump antsibull-docs to 2.11.0. (#1417) (#1419)
  * Adding explanation for combining until with loop (#1367)
  * update codespell ignore lines (#1366) (#1406)
  * Integrate ansible-creator and devtools into the developing
    collections guide (#1302) (#1401)
  * follows up on #1042 to remove smart from uptime script (#1340)
    (#1397)
  * New section on combining variables added (#1383) (#1389)
  * CONTRIBUTING: document backport labels and PR Merging (#1364)
    (#1393)
  * Fix typos in style guide (#1368)
  * MUNI_TECH_WRITERS: Better documented local collections for
    playbooks #1129 (#1315)
  * ci: refresh dev dependencies
  * Add examples to clarify inventory plugin usage (#1347)
  * Merge pull request #1311 from
    TarzanOfJungle/defining-changed-issue
  * Merge pull request #1296 from terezahelanova/feature/#793
  * Merge pull request #1303 from terezahelanova/feature/#96
  * Merge pull request #1283 from Devids10/clarify_example_module
  * Merge pull request #1258 from Devids10/paramiko_contradictions
  * Merge pull request #1275 from ansible/bcoca-patch-2
  * Merge pull request #1293 from terezahelanova/fix/#1199
  * Bump wntrblm/nox from 2024.03.02 to 2024.04.15
  * Add Ansible 9.5.1 porting guide. (#1312)
  * Merge pull request #1300 from ansible/pip-compile/devel/dev
  * Update playbooks_blocks.rst (#1190)
  * Merge pull request #1233 from meizhaohui/patch-1
  * Merge pull request #1277 from ansible/pip-compile/devel/dev
  * Avoid using sh.
  * Bump antsibull-docs to 2.10.0.
* Tue Apr 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.6:
  * Add Ansible 9.4.0 porting guide. (#1238)
  * ci: refresh dev dependencies (#1214)
* Wed Mar 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.5:
  * Merge pull request #1189 from ericzolf/ericzolf-fix-ipaddr
  * Unintended or undocumented functionality may be removed without
    deprecation (#1209) (#1223)
  * Document attributes (#1130) (#1230)
  * Cheat sheet instructions for ansible ad-hoc commands (#1171)
    (#1228)
  * Update playbooks_advanced_syntax.rst (#1208) (#1224)
  * Update testing_units_modules.rst (#1210) (#1220)
  * Add link to antsibull-docs docsite (#1198) (#1207)
  * Trim down the docs banners (#1188) (#1204)
  * Merge pull request #1201 from samccann/fix-nit (#1203)
  * Merge pull request #1172 from ansible/pip-compile/devel/dev
  * Merge pull request #1191 from oraNod/fix-ruff-path
  * Update documentation about vars: in roles: since they're no
    longer added to the play's variables (#1181) (#1186)
  * Fix typo (#1175) (#1184)
  * Data Tagging Delayed to 2.18 (#1182) (#1183)
  * [Needs SC vote] Steering Committee: votes on new members to be
    conducted on the forum; change the chairperson election
    procedure (#1085) (#1170)
  * Merge pull request #1174 from
    ansible/dependabot/github_actions/wntrblm/nox-2024.03.02
  * Add Ansible community 9.3.0 porting guide (#1168)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.4:
  * ci: refresh dev dependencies (#1162)
  * Fix problems with example inventory in the intro_patterns doc
    (#1138) (#1158)
  * Update playbooks_templating_now.rst (#1099) (#1156)
  * Merge pull request #1114 from akira6592/fix-ellipsis
  * Merge pull request #1115 from h3xx/fix-syntax-error
  * Merge pull request #1119 from tomkivlin/tomkivlin-patch-1
  * Remove/update incorrect docs building documentation (#1128)
  * steering committee: update members / past members lists (#1143)
    (#1144)
  * Fix core deprecation cycle example to match reality (#1113)
  * Add example around ansible-galaxy command (#1053)
  * ci: refresh dev dependencies (#1131)
  * Improve role argspec documentation (#1126)
  * Update Ansible 9 porting guide. (#1124) (#1125)
  * Merge pull request #1111 from bcoca/fix_typo
  * ci: refresh dev dependencies (#1091)
  * fix version switcher problem` (#1112)
  * Fix doc prompts (#1074) (#1107)
  * nox: run clone-core session in a venv as well (#1055) (#1060)
  * [network] update note about `gather_network_resources` (#1096)
    (#1104)
  * Add network differences explanation (#1051) (#1072)
  * remove outdated ansible/community links (#913)
  * Collection requirements: undocumented-parameter must only be
    used for deprecated parameters or internal parameters (#989)
    (#1100)
  * Extend Ansible 9 lifecycle to November 2024 (#1023) (#1098)
  * Ansible 10 roadmap (#994) (#1097)
  * Add Ansible community 9.2.0 porting guide (#1087)
  * Bump antsibull-docs to 2.7.0. (#1090)
  * community_steering_committee.rst: update with respect to forum
    and collection requirements (#997)
  * ci: refresh dev dependencies (#1049) (#1061)
  * ci: refresh dev dependencies (#1065) (#1077)
  * Remove 2.10 from build (#1046)
* Tue Jan 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.3:
  * convert core docs to use Ansible sphinx theme (#922) (#1067)
  * fix internal links for ansible forum (#1052) (#1062)
  * added `gather_facts/(yes/no)` (#1003) (#1043)
  * [backport][2.16] Add how to request a working group (#912)
    (#1041)
  * collection_requirements: add meta/execution-environments.yml
    (#871) (#1048)
  * collection requirements/steering committee inclusion policy:
    change (#995) (#1047)
  * Proof reading II (#733) (#1039)
  * fix intersphinx  tuples (#880) (#1038)
  * Update task definition in playbook getting started doc (#1029)
    (#1032)
  * Update Arch Linux bugtracker link (#1027) (#1033)
  * ci: refresh dev dependencies (#1022)
  * corrected `test/` folder to `tests/` (#993) (#1017)
  * docs: Document removal of ConfigureRemotingForAnsible.ps1 #794
    (#984) (#1010)
  * Add documentation about --exclude flag (#978) (#1016)
  * Merge pull request #957 from akira6592/fix-exapmle-role-name
    (#1011)
  * Fixed DCO file link (#1005) (#1007)
  * Update windows_setup.rst to fix link (#766) (#1009)
  * Adds note for more details about variable precedence (#930)
  * Document collection naming (#987)
  * Collection requirements: add seealso with link to Collection
    creator path (#976) (#985)
  * Fix argument_specs.yml example (#956) (#988)
  * Add documentation for the custom Jinja2 global function `undef`
    (#953)
  * clone-core.py: allow specifying custom branch and repo (#954)
  * get_bot_user: use correct username in committer email
  * ci pr_labeler: also use the app token for issues (#636)
  * ci pip-compile: remove duplicate environment key (#633)
  * ci: use Github App token to authenticate (#621)
* Sun Jan 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.2:
  * Retroactivelly add a 2.15 porting guide note about handlers
    (#882)
  * bump approved antsibull-docs version to 2.6.0
  * Update windows_winrm.rst (#910) (#951)
  * documentation_contributions: show how to set up a venv and
    remove outdated notes (#911) (#950)
  * handlers notify example indentation fix (#915) (#947)
  * Improve module developing documenation for deprecation and
    linking (#943) (#946)
  * Merge pull request #937 from Andersson007/add_pr_link (#944)
  * Add Ansible community 8.7.0 porting guide (#938)
  * Add 2.14 and 2.15 CVE porting guide to 2.16 (#932)
  * Merge pull request #929 from anweshadas/pr_porting_guide_9.1.0
    (#936)
  * Ansible 9: Follow ansible-core more closely (#856) (#934)
  * README: consistently use `nox -s` over `nox -e` (#923)
* Sun Jan 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.1:
  * nox pip-compile: allow passing --no-upgrade flag (#883) (#920)
  * add nox make session and revamp contribution docs (#707) (#917)
  * installation_guide/intro: update seealso with respect to
    communication (#869) (#908)
  * Update links in plugin documentation (#859) (#907)
  * installation_distros.rst: fix RST hyperlink syntax (#857)
    (#904)
  * developing_collections_path.rst: fix formatting (#842) (#901)
  * Add the mission statement to the community guide (#854) (#902)
  * Fix Edit on GitHub for templated pages, remove superfluous
    template, fix broken link (#865) (#892)
  * add ansible-galaxy to command cheatsheet (#826) (#898)
  * Fix delegate_to details about inheriting vars from 'all' (#825)
    (#897)
  * Update developing_program_flow_modules.rst (#819) (#895)
  * intro_installation: add EE info (#870) (#894)
  * developing_collections_structure.rst: Add EE collection-level
    metadata link to meta directory subsection (#855) (#890)
  * update python versions in installation guide (#836) (#887)
  * add support for Ansible 9 intersphinx links (#878) (#879)
  * Refs #340: Swap old 'CLA' for the DCO (#598) (#875)
  * Add porting guide for CVE-2023-5764 (#866)
  * Update the information on RouterOS network connections. (#841)
    (#863)
  * update galaxy urls for networking docs' (#822) (#862)
  * ci: refresh dev dependencies (#839)
  * ci: refresh dev dependencies (#813)
  * sphinx: remove usage of deprecated notfound-page options (#827)
  * update logic to make it easier to patch for core vs ansible
    release (#849) (#850)
  * downgrade sphinx to 7.1.2 to fix 404 pages
  * add Ansible 9 changelogs (#831) (#848)
  * update backport instructions to match 2.16 (#799) (#846)
  * Set release version to 9 (#832) (#845)
  * Add Ansible community 9.0.0 porting guide (#843) (#844)
  * developing_collections.rst: add collection creator path (#775)
    (#835)
  * EOL 2.13 in release table (#798) (#810)
  * communication.rst: remove inactive security WG (#828) (#833)
  * communication.rst: update Docs WG reference (#785) (#802)
  * communication.rst: update MySQL WG to point to the forum group
    page (#795) (#805)
  * Update the Note for certificate authentication with a TLS 1.3
    connection in windows_winrm.rst  (#757) (#781)
  * [PR #788/2a485247 backport][stable-2.16] Add Ansible community
    8.6.0 porting guide (#791)
  * Porting guide for 9.0.0b1. (#787) (#790)
  * update versioning for 2.16 (#755) (#783)
  * communication.rst: Make WG a top-level section (#750) (#764)
  * intro_installation: pass --include-injected in pipx upgrade
    example (#745) (#768)
  * Replaced the AWX mailing list with the AWX Forum page. (#769)
    (#777)
  * set release version to 2.16 (#756)
* Sun Jan 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.0:
  This tag contains a snapshot of the ansible-documentation
  stable-2.16 branch at the time of the ansible-core 2.16.0
  release.
* Tue Dec 12 2023 kastl@b1-systems.de
- Update to version 2.15.8:
  * Retroactivelly add a 2.15 porting guide note about handlers
    (#882)
  * bump approved antsibull-docs version to 2.6.0
  * documentation_contributions: show how to set up a venv and
    remove outdated notes (#911) (#949)
  * Update windows_winrm.rst (#910) (#952)
  * handlers notify example indentation fix (#915) (#948)
  * Merge pull request #937 from Andersson007/add_pr_link (#945)
  * Add Ansible community 8.7.0 porting guide (#938)
  * Add porting guide for CVE-2023-5764 (#933)
  * ci: refresh dev dependencies (#914)
  * README: consistently use `nox -s` over `nox -e` (#923)
* Tue Dec  5 2023 kastl@b1-systems.de
- Update to version 2.15.7:
  * nox pip-compile: allow passing --no-upgrade flag (#883) (#919)
  * add nox make session and revamp contribution docs (#707) (#916)
  * installation_guide/intro: update seealso with respect to
    communication (#869) (#909)
  * Update links in plugin documentation (#859) (#906)
  * installation_distros.rst: fix RST hyperlink syntax (#857)
    (#903)
  * Updated loop docs (#838) (#899)
  * intro_installation: add EE info (#870) (#893)
  * Fix Edit on GitHub for templated pages, remove superfluous
    template, fix broken link (#865) (#891)
  * developing_collections_structure.rst: Add EE collection-level
    metadata link to meta directory subsection (#855) (#889)
  * Add the mission statement to the community guide (#854) (#888)
  * update python versions in installation guide (#836) (#886)
  * add ansible-galaxy to command cheatsheet (#826) (#884)
  * Refs #340: Swap old 'CLA' for the DCO (#598) (#874)
  * ci: refresh dev dependencies (#839) (#861)
  * Add porting guide for CVE-2023-5764 (#867)
  * Update the information on RouterOS network connections. (#841)
    (#864)
  * update backport instructions to match 2.16 (#799) (#847)
  * Fix delegate_to details about inheriting vars from 'all' (#825)
    (#834)
  * communication.rst: Make WG a top-level section (#750) (#806)
  * EOL 2.13 in release table (#798) (#808)
  * ci: refresh dev dependencies (#813) (#814)
  * Update developing_program_flow_modules.rst (#819) (#820)
  * update galaxy urls for networking docs' (#822) (#823)
  * communication.rst: remove inactive security WG (#828) (#830)
  * communication.rst: update MySQL WG to point to the forum group
    page (#795) (#803)
  * communication.rst: update Docs WG reference (#785) (#800)
  * Update the Note for certificate authentication with a TLS 1.3
    connection in windows_winrm.rst  (#757) (#780)
  * [2.15] Add Ansible community 8.6.0 porting guide (#788) (#792)
  * update versioning for 2.16 (#755) (#779)
  * intro_installation: pass --include-injected in pipx upgrade
    example (#745) (#767)
  * Replaced the AWX mailing list with the AWX Forum page. (#769)
    (#776)
* Tue Nov  7 2023 kastl@b1-systems.de
- Update to version 2.15.6:
  * ci: refresh dev dependencies (#770)
  * Fixed equalto test filter (#758) (#759)
  * ci: refresh dev dependencies (#741)
  * nox and README: log PIP_CONSTRAINT value and add Dependency file docs (#730) (#737)
  * [stable-2.15] installation_guide/intro_configuration.rst: improve readability
  * Proof reading (#616) (#729)
  * [PR #668/8d847046 backport] Integrate docs checkers into the noxfile (#727)
  * ci: refresh dev dependencies (#721) (#722)
  * Update JSON queries examples (#690) (#704)
  * communication.rst: other forum-related tweaks (#669) (#698)
  * documentation_contributions: use tests/checkers.py (#706) (#712)
  * Update slicing in inventory pattern (#541) (#693)
  * [stable-2.15] Unify the Sphinx's `conf.py` files (#431) (#627)
  * Update shebang sanity test docs to match test (#677) (#687)
  * Update example using special variables in resuce section of blocks (#671) (#680)
  * ci: refresh dev dependencies (#682)
  * ci: refresh dev dependencies (#672)
  * Use a working exponential backoff example (#607) (#660)
  * Rename tests/sanity.py to tests/checkers.py (#563) (#663)
  * Added delegation info to special vars (#629) (#659)
  * Add forum info to collection maintainer guidelines (#549) (#655)
  * Fix#129 (#201) (#613)
  * Update PowerShell Codeblock (#489) (#603)
  * Changed it's to it is in all .rst files (#491)
  * Clarify that two releases will happen on two separate days, and clarify which one will happen first (#39)
  * pr_labeler: stop adding needs_triage labels to new PRs (#643) (#645)
  * ci: refresh dev dependencies (#638) (#641)
  * [stable-2.15] Add RST spellcheck (#524) (#623)
  * corrected cli for help (#599) (#600)
  * communication.rst: Add a link to the forum group list (#571) (#594)
  * developing_collections_structure.rs: Fix link formatting (#570) (#591)
  * Testing collections guide: add GHA info and link to sample matrix (#569) (#588)
  * issue #560 fix broken url in script (#568) (#585)
  * Document how to bump dependencies (#446) (#614)
  * ci: refresh dev dependencies (#608) (#609)
  * Merge pull request #27 from oraNod/issue-26/add-intro-getting-started (#526)
  * Spellingfix (#494) (#583)
  * communication.rst: fix link (#495) (#580)
  * More info on delegation behaviours (#527) (#582)
  * Replace i.e with that is  (#490) (#565)
  * Fix for : Replace all occurrences of via to with #459 (#479) (#578)
  * issue-457: Update all occurrences of Ansible core to Ansible Core (#471) (#575)
  * communication.rst: Add Release Management WG info (#438) (#574)
  * Update collections_installing.rst (#412) (#573)
  * communication.rst: add forum info (#392) (#572)
  * Integrate `docs/bin/*.py` files into the nox config (#529) (#562)
  * Add Ansible community 8.5.0 porting guide (#556) (#557)
  * fix molecule link in contributor path page (#538) (#551)
  * Add Arch installation instructions in the installation_distros documentation (#522) (#545)
  * ci: refresh dev dependencies (#548)
* Tue Nov  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 2.15.6:
  This tag contains a snapshot of the ansible-documentation
  stable-2.15 branch at the time of the ansible-core 2.15.6
  release.
* Tue Oct 10 2023 kastl@b1-systems.de
- Update to version 2.15.5:
  This tag contains a snapshot of the ansible-documentation
  stable-2.15 branch at the time of the ansible-core 2.15.5
  release.
  * better description of 'short' (#528) (#533)
  * Fix typo (#454) (#517)
  * Add preferred terms list to style guide (#386) (#516)
  * Update automationhub.rst #477 (#485) (#492)
  * pr_labeler: change link to the DAWGs meeting agenda (#497)
    (#504)
  * Bump antsibull-docs to 2.5.0 (#467) (#480)
  * Bump docs build requirements for stable-2.15. (#448)
  * Update 'For instance' to 'For example' (#472) (#475)
  * Prepare Galaxy guides for GalaxyNG (#388) (#474)
  * [stable-2.15] ci: refresh dev dependencies (#447)
  * Add label to 'collections:' keyword. (#434) (#435)
  * Backport/2.15/425 - Change banner for Contributor summit (#430)
  * Update developing_collections_creating.rst (#414) (#416)
  * Removing [] from --tags and --skip-tags (#406) (#421)
  * readthedocs stable-2.15 (#413)
  * added example using the variables (#393) (#394)
  * ci: refresh dev dependencies (#402) (#407)
  * build(deps): bump actions/checkout from 3 to 4 (#372) (#405)
  * Add Ansible community 8.4.0 porting guide (#384) (#385)
* Tue Sep 12 2023 kastl@b1-systems.de
- Update to version 2.15.4:
  This tag contains a snapshot of the ansible-documentation
  stable-2.15 branch at the time of the ansible-core 2.15.4
  release.
* Fri Sep  8 2023 Johannes Kastl <kastl@b1-systems.de>
- new package ansible-documentation
